==> 0.3.0%2B3.tar.gz: lib/etc/utility.dart <==
part of viltage;

class Utility {
	static render(List<List<Entity>> entities, List<List<CharNode>> charArray) {
		for(int i = 0; i < entities.length; i++) {
			for(int j = 0; j < entities[i].length; j++) {
				entities[i][j].render(charArray);
			}
		}
	}
	  
	static draw(CanvasRenderingContext2D ctx, int offX, int offY, VilTAGE viltage) {
	  List<List<CharNode>> charArray = viltage.charArray;

	  for(int i = 0; i < charArray.length; i++) {
			for(int j = 0; j < charArray[0].length; j++) {
			  ctx.drawImage(getImage(charArray[i][j], viltage), j*offX, i*offY);
  		}
	  }
	}
	
	static bool printCaching = false;
	
	static CanvasElement getImage(CharNode cn, VilTAGE viltage) {
	  CanvasElement image;
      
	  cachedNodes.forEach((k, v) {
	    if(k == cn) {
	      image = v;
	    }
	  });
	  
	  if(image == null) {
	    image = createImage(cn, viltage);
	    if(printCaching) print('Created cache of: "${cn.char}" with background color: "${cn.backgroundColor}" and color: "${cn.color}"');
	  }
	  
	  return image;
	}
	
	static CanvasElement createImage(CharNode cn, VilTAGE viltage) {
	  CanvasElement ce = new CanvasElement(width: viltage.offX, height: viltage.offY);
	  
	  if(cn.backgroundColor == "none") ce.context2D.fillStyle = viltage.backgroundColor;
	  else ce.context2D.fillStyle = cn.backgroundColor;

	  ce.context2D.fillRect(0, 0, ce.width, ce.height);
	  
	  ce.context2D.fillStyle = cn.color;
	  ce.context2D.font = viltage.ce.context2D.font;
	  
	  if(cn.char.length <= 1 && cn.char != " ") ce.context2D.fillText(cn.char, viltage.offX/4-viltage.fontSize/10, viltage.offY/3*2 + viltage.fontSize/10);
	  
	  cachedNodes[cn] = ce;
	  return ce;
	}
	
	static HashMap<CharNode, CanvasElement> cachedNodes = new HashMap<CharNode, CanvasElement>();
	  
	static update(List<List<Entity>> entities, double delta) {
		for(int i = 0; i < entities.length; i++) {
			for(int j = 0; j < entities[i].length; j++) {
				entities[i][j].update(delta);
				entities[i][j].updateAnimations(delta);
			}
		}
	}
}

==> 0.3.1%2B3.tar.gz: lib/etc/utility.dart <==
part of viltage;

class Utility {
	static render(List<List<Entity>> entities, List<List<CharNode>> charArray) {
		for(int i = 0; i < entities.length; i++) {
			for(int j = 0; j < entities[i].length; j++) {
				entities[i][j].render(charArray);
			}
		}
	}
	  
	static draw(CanvasRenderingContext2D ctx, int offX, int offY, VilTAGE viltage) {
	  List<List<CharNode>> charArray = viltage.charArray;

	  for(int i = 0; i < charArray.length; i++) {
			for(int j = 0; j < charArray[0].length; j++) {
			  ctx.drawImage(getImage(charArray[i][j], viltage), j*offX, i*offY);
  		}
	  }
	}
	
	static bool printCaching = false;
	
	static CanvasElement getImage(CharNode cn, VilTAGE viltage) {
	  CanvasElement image;
      
	  cachedNodes.forEach((k, v) {
	    if(k.sameValueAs(cn)) {
	      image = v;
	    }
	  });
	  
	  if(image == null) {
	    image = createImage(cn, viltage);
	    if(printCaching) print('Cached "${cn.char}" background color: "${cn.backgroundColor}" color: "${cn.color}" font: "${cn.fontName=="none"?viltage.fontName:cn.fontName}" bold: "${cn.bold}" italic: "${cn.italic}"');
	  }
	  
	  return image;
	}
	
	static CanvasElement createImage(CharNode cn, VilTAGE viltage) {
	  CanvasElement ce = new CanvasElement(width: viltage.offX, height: viltage.offY);
	  
	  if(cn.backgroundColor == "none") ce.context2D.fillStyle = viltage.backgroundColor;
	  else ce.context2D.fillStyle = cn.backgroundColor;

	  ce.context2D.fillRect(0, 0, ce.width, ce.height);
	  
	  ce.context2D.fillStyle = cn.color;
	  ce.context2D.font = "${cn.italic?"italic":""} ${cn.bold?"bold":""} ${viltage.fontSize}px ${cn.fontName=="none"?viltage.fontName:cn.fontName}";
	  
	  if(cn.char.length <= 1 && cn.char != " ") ce.context2D.fillText(cn.char, viltage.offX/4-viltage.fontSize/10, viltage.offY/3*2 + viltage.fontSize/10);
	  
	  cachedNodes[cn.copy()] = ce;
	  return ce;
	}
	
	static HashMap<CharNode, CanvasElement> cachedNodes = new HashMap<CharNode, CanvasElement>();
	  
	static update(List<List<Entity>> entities, double delta) {
		for(int i = 0; i < entities.length; i++) {
			for(int j = 0; j < entities[i].length; j++) {
				entities[i][j].update(delta);
				entities[i][j].updateAnimations(delta);
			}
		}
	}
}
